==> json-joy-9.0.0.tgz: package/esm/json-pack/json/JsonEncoder.js <==
import { toBase64Bin } from '../../util/base64/toBase64Bin';
export class JsonEncoder {
    writer;
    constructor(writer) {
        this.writer = writer;
    }
    encode(value) {
        this.writeAny(value);
        return this.writer.flush();
    }
    writeAny(value) {
        switch (typeof value) {
            case 'boolean':
                return this.writeBoolean(value);
            case 'number':
                return this.writeNumber(value);
            case 'string':
                return this.writeStr(value);
            case 'object': {
                if (value === null)
                    return this.writeNull();
                const constructor = value.constructor;
                switch (constructor) {
                    case Array:
                        return this.writeArr(value);
                    case Uint8Array:
                        return this.writeBin(value);
                    default:
                        return this.writeObj(value);
                }
            }
            default:
                return this.writeNull();
        }
    }
    writeNull() {
        this.writer.u32(0x6e756c6c);
    }
    writeBoolean(bool) {
        if (bool)
            this.writer.u32(0x74727565);
        else
            this.writer.u8u32(0x66, 0x616c7365);
    }
    writeNumber(num) {
        const str = num.toString();
        this.writer.ascii(str);
    }
    writeInteger(int) {
        this.writeNumber(int >> 0 === int ? int : Math.trunc(int));
    }
    writeUInteger(uint) {
        this.writeInteger(uint < 0 ? -uint : uint);
    }
    writeFloat(float) {
        this.writeNumber(float);
    }
    writeBin(buf) {
        const writer = this.writer;
        const length = buf.length;
        writer.ensureCapacity(38 + 3 + (length << 1));
        const view = writer.view;
        let x = writer.x;
        view.setUint32(x, 0x22_64_61_74);
        x += 4;
        view.setUint32(x, 0x61_3a_61_70);
        x += 4;
        view.setUint32(x, 0x70_6c_69_63);
        x += 4;
        view.setUint32(x, 0x61_74_69_6f);
        x += 4;
        view.setUint32(x, 0x6e_2f_6f_63);
        x += 4;
        view.setUint32(x, 0x74_65_74_2d);
        x += 4;
        view.setUint32(x, 0x73_74_72_65);
        x += 4;
        view.setUint32(x, 0x61_6d_3b_62);
        x += 4;
        view.setUint32(x, 0x61_73_65_36);
        x += 4;
        view.setUint16(x, 0x34_2c);
        x += 2;
        x = toBase64Bin(buf, 0, length, view, x);
        writer.uint8[x++] = 0x22;
        writer.x = x;
    }
    writeStr(str) {
        const writer = this.writer;
        const length = str.length;
        writer.ensureCapacity(length * 5 + 2);
        if (length < 256) {
            let x = writer.x;
            const uint8 = writer.uint8;
            uint8[x++] = 0x22;
            for (let i = 0; i < length; i++) {
                const code = str.charCodeAt(i);
                switch (code) {
                    case 34:
                    case 92:
                        uint8[x++] = 0x5c;
                        break;
                }
                if (code < 32 || code > 126) {
                    writer.utf8(JSON.stringify(str));
                    return;
                }
                else
                    uint8[x++] = code;
            }
            uint8[x++] = 0x22;
            writer.x = x;
            return;
        }
        writer.utf8(JSON.stringify(str));
    }
    writeAsciiStr(str) {
        const length = str.length;
        const writer = this.writer;
        writer.ensureCapacity(length * 2 + 2);
        const uint8 = writer.uint8;
        let x = writer.x;
        uint8[x++] = 0x22;
        for (let i = 0; i < length; i++) {
            const code = str.charCodeAt(i);
            switch (code) {
                case 34:
                case 92:
                    uint8[x++] = 0x5c;
                    break;
            }
            uint8[x++] = code;
        }
        uint8[x++] = 0x22;
        writer.x = x;
    }
    writeArr(arr) {
        const writer = this.writer;
        writer.u8(0x5b);
        const length = arr.length;
        const last = length - 1;
        for (let i = 0; i < last; i++) {
            this.writeAny(arr[i]);
            writer.u8(0x2c);
        }
        if (last >= 0)
            this.writeAny(arr[last]);
        writer.u8(0x5d);
    }
    writeStartArr() {
        this.writer.u8(0x5b);
    }
    writeEndArr() {
        this.writer.u8(0x5d);
    }
    writeArrSeparator() {
        this.writer.u8(0x2c);
    }
    writeObj(obj) {
        const writer = this.writer;
        const keys = Object.keys(obj);
        const length = keys.length;
        if (!length)
            return writer.u16(0x7b7d);
        writer.u8(0x7b);
        for (let i = 0; i < length; i++) {
            const key = keys[i];
            const value = obj[key];
            this.writeStr(key);
            writer.u8(0x3a);
            this.writeAny(value);
            writer.u8(0x2c);
        }
        writer.uint8[writer.x - 1] = 0x7d;
    }
    writeStartObj() {
        this.writer.u8(0x7b);
    }
    writeEndObj() {
        this.writer.u8(0x7d);
    }
    writeObjSeparator() {
        this.writer.u8(0x2c);
    }
    writeObjKeySeparator() {
        this.writer.u8(0x3a);
    }
}

==> json-joy-9.3.0.tgz: package/esm/json-pack/json/JsonEncoder.js <==
import { toBase64Bin } from '../../util/base64/toBase64Bin';
export class JsonEncoder {
    writer;
    constructor(writer) {
        this.writer = writer;
    }
    encode(value) {
        const writer = this.writer;
        writer.reset();
        this.writeAny(value);
        return writer.flush();
    }
    encodeFast(value) {
        const writer = this.writer;
        writer.reset();
        this.writeAny(value);
        return writer.flushSlice();
    }
    writeAny(value) {
        switch (typeof value) {
            case 'boolean':
                return this.writeBoolean(value);
            case 'number':
                return this.writeNumber(value);
            case 'string':
                return this.writeStr(value);
            case 'object': {
                if (value === null)
                    return this.writeNull();
                const constructor = value.constructor;
                switch (constructor) {
                    case Array:
                        return this.writeArr(value);
                    case Uint8Array:
                        return this.writeBin(value);
                    default:
                        return this.writeObj(value);
                }
            }
            default:
                return this.writeNull();
        }
    }
    writeNull() {
        this.writer.u32(0x6e756c6c);
    }
    writeBoolean(bool) {
        if (bool)
            this.writer.u32(0x74727565);
        else
            this.writer.u8u32(0x66, 0x616c7365);
    }
    writeNumber(num) {
        const str = num.toString();
        this.writer.ascii(str);
    }
    writeInteger(int) {
        this.writeNumber(int >> 0 === int ? int : Math.trunc(int));
    }
    writeUInteger(uint) {
        this.writeInteger(uint < 0 ? -uint : uint);
    }
    writeFloat(float) {
        this.writeNumber(float);
    }
    writeBin(buf) {
        const writer = this.writer;
        const length = buf.length;
        writer.ensureCapacity(38 + 3 + (length << 1));
        const view = writer.view;
        let x = writer.x;
        view.setUint32(x, 0x22_64_61_74);
        x += 4;
        view.setUint32(x, 0x61_3a_61_70);
        x += 4;
        view.setUint32(x, 0x70_6c_69_63);
        x += 4;
        view.setUint32(x, 0x61_74_69_6f);
        x += 4;
        view.setUint32(x, 0x6e_2f_6f_63);
        x += 4;
        view.setUint32(x, 0x74_65_74_2d);
        x += 4;
        view.setUint32(x, 0x73_74_72_65);
        x += 4;
        view.setUint32(x, 0x61_6d_3b_62);
        x += 4;
        view.setUint32(x, 0x61_73_65_36);
        x += 4;
        view.setUint16(x, 0x34_2c);
        x += 2;
        x = toBase64Bin(buf, 0, length, view, x);
        writer.uint8[x++] = 0x22;
        writer.x = x;
    }
    writeStr(str) {
        const writer = this.writer;
        const length = str.length;
        writer.ensureCapacity(length * 5 + 2);
        if (length < 256) {
            let x = writer.x;
            const uint8 = writer.uint8;
            uint8[x++] = 0x22;
            for (let i = 0; i < length; i++) {
                const code = str.charCodeAt(i);
                switch (code) {
                    case 34:
                    case 92:
                        uint8[x++] = 0x5c;
                        break;
                }
                if (code < 32 || code > 126) {
                    writer.utf8(JSON.stringify(str));
                    return;
                }
                else
                    uint8[x++] = code;
            }
            uint8[x++] = 0x22;
            writer.x = x;
            return;
        }
        writer.utf8(JSON.stringify(str));
    }
    writeAsciiStr(str) {
        const length = str.length;
        const writer = this.writer;
        writer.ensureCapacity(length * 2 + 2);
        const uint8 = writer.uint8;
        let x = writer.x;
        uint8[x++] = 0x22;
        for (let i = 0; i < length; i++) {
            const code = str.charCodeAt(i);
            switch (code) {
                case 34:
                case 92:
                    uint8[x++] = 0x5c;
                    break;
            }
            uint8[x++] = code;
        }
        uint8[x++] = 0x22;
        writer.x = x;
    }
    writeArr(arr) {
        const writer = this.writer;
        writer.u8(0x5b);
        const length = arr.length;
        const last = length - 1;
        for (let i = 0; i < last; i++) {
            this.writeAny(arr[i]);
            writer.u8(0x2c);
        }
        if (last >= 0)
            this.writeAny(arr[last]);
        writer.u8(0x5d);
    }
    writeStartArr() {
        this.writer.u8(0x5b);
    }
    writeEndArr() {
        this.writer.u8(0x5d);
    }
    writeArrSeparator() {
        this.writer.u8(0x2c);
    }
    writeObj(obj) {
        const writer = this.writer;
        const keys = Object.keys(obj);
        const length = keys.length;
        if (!length)
            return writer.u16(0x7b7d);
        writer.u8(0x7b);
        for (let i = 0; i < length; i++) {
            const key = keys[i];
            const value = obj[key];
            this.writeStr(key);
            writer.u8(0x3a);
            this.writeAny(value);
            writer.u8(0x2c);
        }
        writer.uint8[writer.x - 1] = 0x7d;
    }
    writeStartObj() {
        this.writer.u8(0x7b);
    }
    writeEndObj() {
        this.writer.u8(0x7d);
    }
    writeObjSeparator() {
        this.writer.u8(0x2c);
    }
    writeObjKeySeparator() {
        this.writer.u8(0x3a);
    }
}
